@@ -51,61 +51,61 @@ def make_request(app, protocol):
     return maker
 
 
-async def test_nonstarted_ping():
+async def test_nonstarted_ping() -> None:
     ws = WebSocketResponse()
     with pytest.raises(RuntimeError):
         await ws.ping()
 
 
-async def test_nonstarted_pong():
+async def test_nonstarted_pong() -> None:
     ws = WebSocketResponse()
     with pytest.raises(RuntimeError):
         await ws.pong()
 
 
-async def test_nonstarted_send_str():
+async def test_nonstarted_send_str() -> None:
     ws = WebSocketResponse()
     with pytest.raises(RuntimeError):
         await ws.send_str('string')
 
 
-async def test_nonstarted_send_bytes():
+async def test_nonstarted_send_bytes() -> None:
     ws = WebSocketResponse()
     with pytest.raises(RuntimeError):
         await ws.send_bytes(b'bytes')
 
 
-async def test_nonstarted_send_json():
+async def test_nonstarted_send_json() -> None:
     ws = WebSocketResponse()
     with pytest.raises(RuntimeError):
         await ws.send_json({'type': 'json'})
 
 
-async def test_nonstarted_close():
+async def test_nonstarted_close() -> None:
     ws = WebSocketResponse()
     with pytest.raises(RuntimeError):
         await ws.close()
 
 
-async def test_nonstarted_receive_str():
+async def test_nonstarted_receive_str() -> None:
     ws = WebSocketResponse()
     with pytest.raises(RuntimeError):
         await ws.receive_str()
 
 
-async def test_nonstarted_receive_bytes():
+async def test_nonstarted_receive_bytes() -> None:
     ws = WebSocketResponse()
     with pytest.raises(RuntimeError):
         await ws.receive_bytes()
 
 
-async def test_nonstarted_receive_json():
+async def test_nonstarted_receive_json() -> None:
     ws = WebSocketResponse()
     with pytest.raises(RuntimeError):
         await ws.receive_json()
 
 
-async def test_receive_str_nonstring(make_request):
+async def test_receive_str_nonstring(make_request) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -119,7 +119,7 @@ async def test_receive_str_nonstring(make_request):
         await ws.receive_str()
 
 
-async def test_receive_bytes_nonsbytes(make_request):
+async def test_receive_bytes_nonsbytes(make_request) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -133,7 +133,7 @@ async def test_receive_bytes_nonsbytes(make_request):
         await ws.receive_bytes()
 
 
-async def test_send_str_nonstring(make_request):
+async def test_send_str_nonstring(make_request) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -141,7 +141,7 @@ async def test_send_str_nonstring(make_request):
         await ws.send_str(b'bytes')
 
 
-async def test_send_bytes_nonbytes(make_request):
+async def test_send_bytes_nonbytes(make_request) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -149,7 +149,7 @@ async def test_send_bytes_nonbytes(make_request):
         await ws.send_bytes('string')
 
 
-async def test_send_json_nonjson(make_request):
+async def test_send_json_nonjson(make_request) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -157,66 +157,66 @@ async def test_send_json_nonjson(make_request):
         await ws.send_json(set())
 
 
-async def test_write_non_prepared():
+async def test_write_non_prepared() -> None:
     ws = WebSocketResponse()
     with pytest.raises(RuntimeError):
         await ws.write(b'data')
 
 
-def test_websocket_ready():
+def test_websocket_ready() -> None:
     websocket_ready = WebSocketReady(True, 'chat')
     assert websocket_ready.ok is True
     assert websocket_ready.protocol == 'chat'
 
 
-def test_websocket_not_ready():
+def test_websocket_not_ready() -> None:
     websocket_ready = WebSocketReady(False, None)
     assert websocket_ready.ok is False
     assert websocket_ready.protocol is None
 
 
-def test_websocket_ready_unknown_protocol():
+def test_websocket_ready_unknown_protocol() -> None:
     websocket_ready = WebSocketReady(True, None)
     assert websocket_ready.ok is True
     assert websocket_ready.protocol is None
 
 
-def test_bool_websocket_ready():
+def test_bool_websocket_ready() -> None:
     websocket_ready = WebSocketReady(True, None)
     assert bool(websocket_ready) is True
 
 
-def test_bool_websocket_not_ready():
+def test_bool_websocket_not_ready() -> None:
     websocket_ready = WebSocketReady(False, None)
     assert bool(websocket_ready) is False
 
 
-def test_can_prepare_ok(make_request):
+def test_can_prepare_ok(make_request) -> None:
     req = make_request('GET', '/', protocols=True)
     ws = WebSocketResponse(protocols=('chat',))
     assert WebSocketReady(True, 'chat') == ws.can_prepare(req)
 
 
-def test_can_prepare_unknown_protocol(make_request):
+def test_can_prepare_unknown_protocol(make_request) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     assert WebSocketReady(True, None) == ws.can_prepare(req)
 
 
-def test_can_prepare_invalid_method(make_request):
+def test_can_prepare_invalid_method(make_request) -> None:
     req = make_request('POST', '/')
     ws = WebSocketResponse()
     assert WebSocketReady(False, None) == ws.can_prepare(req)
 
 
-def test_can_prepare_without_upgrade(make_request):
+def test_can_prepare_without_upgrade(make_request) -> None:
     req = make_request('GET', '/',
                        headers=CIMultiDict({}))
     ws = WebSocketResponse()
     assert WebSocketReady(False, None) == ws.can_prepare(req)
 
 
-async def test_can_prepare_started(make_request):
+async def test_can_prepare_started(make_request) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -226,13 +226,13 @@ async def test_can_prepare_started(make_request):
     assert 'Already started' in str(ctx.value)
 
 
-def test_closed_after_ctor():
+def test_closed_after_ctor() -> None:
     ws = WebSocketResponse()
     assert not ws.closed
     assert ws.close_code is None
 
 
-async def test_send_str_closed(make_request, mocker):
+async def test_send_str_closed(make_request, mocker) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -244,7 +244,7 @@ async def test_send_str_closed(make_request, mocker):
     assert ws_logger.warning.called
 
 
-async def test_send_bytes_closed(make_request, mocker):
+async def test_send_bytes_closed(make_request, mocker) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -256,7 +256,7 @@ async def test_send_bytes_closed(make_request, mocker):
     assert ws_logger.warning.called
 
 
-async def test_send_json_closed(make_request, mocker):
+async def test_send_json_closed(make_request, mocker) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -268,7 +268,7 @@ async def test_send_json_closed(make_request, mocker):
     assert ws_logger.warning.called
 
 
-async def test_ping_closed(make_request, mocker):
+async def test_ping_closed(make_request, mocker) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -280,7 +280,7 @@ async def test_ping_closed(make_request, mocker):
     assert ws_logger.warning.called
 
 
-async def test_pong_closed(make_request, mocker):
+async def test_pong_closed(make_request, mocker) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -292,7 +292,7 @@ async def test_pong_closed(make_request, mocker):
     assert ws_logger.warning.called
 
 
-async def test_close_idempotent(make_request):
+async def test_close_idempotent(make_request) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -302,14 +302,14 @@ async def test_close_idempotent(make_request):
     assert not (await ws.close(code=2, message='message2'))
 
 
-async def test_prepare_invalid_method(make_request):
+async def test_prepare_invalid_method(make_request) -> None:
     req = make_request('POST', '/')
     ws = WebSocketResponse()
     with pytest.raises(HTTPMethodNotAllowed):
         await ws.prepare(req)
 
 
-async def test_prepare_without_upgrade(make_request):
+async def test_prepare_without_upgrade(make_request) -> None:
     req = make_request('GET', '/',
                        headers=CIMultiDict({}))
     ws = WebSocketResponse()
@@ -317,19 +317,19 @@ async def test_prepare_without_upgrade(make_request):
         await ws.prepare(req)
 
 
-async def test_wait_closed_before_start():
+async def test_wait_closed_before_start() -> None:
     ws = WebSocketResponse()
     with pytest.raises(RuntimeError):
         await ws.close()
 
 
-async def test_write_eof_not_started():
+async def test_write_eof_not_started() -> None:
     ws = WebSocketResponse()
     with pytest.raises(RuntimeError):
         await ws.write_eof()
 
 
-async def test_write_eof_idempotent(make_request):
+async def test_write_eof_idempotent(make_request) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -341,7 +341,7 @@ async def test_write_eof_idempotent(make_request):
     await ws.write_eof()
 
 
-async def test_receive_eofstream_in_reader(make_request, loop):
+async def test_receive_eofstream_in_reader(make_request, loop) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -360,7 +360,7 @@ async def test_receive_eofstream_in_reader(make_request, loop):
     assert ws.closed
 
 
-async def test_receive_exc_in_reader(make_request, loop):
+async def test_receive_exc_in_reader(make_request, loop) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -380,7 +380,7 @@ async def test_receive_exc_in_reader(make_request, loop):
     assert ws.exception() is exc
 
 
-async def test_receive_cancelled(make_request, loop):
+async def test_receive_cancelled(make_request, loop) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -394,7 +394,7 @@ async def test_receive_cancelled(make_request, loop):
         await ws.receive()
 
 
-async def test_receive_timeouterror(make_request, loop):
+async def test_receive_timeouterror(make_request, loop) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -408,7 +408,7 @@ async def test_receive_timeouterror(make_request, loop):
         await ws.receive()
 
 
-async def test_multiple_receive_on_close_connection(make_request):
+async def test_multiple_receive_on_close_connection(make_request) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -424,7 +424,7 @@ async def test_multiple_receive_on_close_connection(make_request):
         await ws.receive()
 
 
-async def test_concurrent_receive(make_request):
+async def test_concurrent_receive(make_request) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
@@ -434,7 +434,7 @@ async def test_concurrent_receive(make_request):
         await ws.receive()
 
 
-async def test_close_exc(make_request, loop, mocker):
+async def test_close_exc(make_request, loop, mocker) -> None:
     req = make_request('GET', '/')
 
     ws = WebSocketResponse()
@@ -460,7 +460,7 @@ async def test_close_exc(make_request, loop, mocker):
     assert ws.close_code == 1006
 
 
-async def test_close_exc2(make_request):
+async def test_close_exc2(make_request) -> None:
 
     req = make_request('GET', '/')
     ws = WebSocketResponse()
@@ -479,7 +479,7 @@ async def test_close_exc2(make_request):
         await ws.close()
 
 
-async def test_prepare_twice_idempotent(make_request):
+async def test_prepare_twice_idempotent(make_request) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
 
@@ -488,7 +488,7 @@ async def test_prepare_twice_idempotent(make_request):
     assert impl1 is impl2
 
 
-async def test_send_with_per_message_deflate(make_request, mocker):
+async def test_send_with_per_message_deflate(make_request, mocker) -> None:
     req = make_request('GET', '/')
     ws = WebSocketResponse()
     await ws.prepare(req)
