@@ -1,7 +1,6 @@
 """Tests for aiohttp/worker.py"""
 import asyncio
 import os
-import pathlib
 import socket
 import ssl
 from unittest import mock
@@ -9,8 +8,6 @@ from unittest import mock
 import pytest
 
 from aiohttp import web
-from aiohttp.test_utils import make_mocked_coro
-
 
 base_worker = pytest.importorskip('aiohttp.worker')
 
@@ -43,13 +40,15 @@ class BaseTestWorker:
         self.wsgi = web.Application()
 
 
-class AsyncioWorker(BaseTestWorker, base_worker.GunicornWebWorker):  # type: ignore  # noqa
+class AsyncioWorker(BaseTestWorker,  # type: ignore
+                    base_worker.GunicornWebWorker):
     pass
 
 
 PARAMS = [AsyncioWorker]
 if uvloop is not None:
-    class UvloopWorker(BaseTestWorker, base_worker.GunicornUVLoopWebWorker):  # type: ignore  # noqa
+    class UvloopWorker(BaseTestWorker,  # type: ignore
+                       base_worker.GunicornUVLoopWebWorker):
         pass
 
     PARAMS.append(UvloopWorker)
@@ -79,12 +78,13 @@ def test_run(worker, loop) -> None:
     worker.log = mock.Mock()
     worker.cfg = mock.Mock()
     worker.cfg.access_log_format = ACCEPTABLE_LOG_FORMAT
+    worker.cfg.is_ssl = False
+    worker.sockets = []
 
     worker.loop = loop
-    worker._run = make_mocked_coro(None)
     with pytest.raises(SystemExit):
         worker.run()
-    assert worker._run.called
+    worker.log.exception.assert_not_called()
     assert loop.is_closed()
 
 
@@ -92,6 +92,8 @@ def test_run_async_factory(worker, loop) -> None:
     worker.log = mock.Mock()
     worker.cfg = mock.Mock()
     worker.cfg.access_log_format = ACCEPTABLE_LOG_FORMAT
+    worker.cfg.is_ssl = False
+    worker.sockets = []
     app = worker.wsgi
 
     async def make_app():
@@ -99,10 +101,24 @@ def test_run_async_factory(worker, loop) -> None:
     worker.wsgi = make_app
 
     worker.loop = loop
-    worker._run = make_mocked_coro(None)
+    worker.alive = False
     with pytest.raises(SystemExit):
         worker.run()
-    assert worker._run.called
+    worker.log.exception.assert_not_called()
+    assert loop.is_closed()
+
+
+def test_run_not_app(worker, loop) -> None:
+    worker.log = mock.Mock()
+    worker.cfg = mock.Mock()
+    worker.cfg.access_log_format = ACCEPTABLE_LOG_FORMAT
+
+    worker.loop = loop
+    worker.wsgi = "not-app"
+    worker.alive = False
+    with pytest.raises(SystemExit):
+        worker.run()
+    worker.log.exception.assert_called_with('Exception in gunicorn worker')
     assert loop.is_closed()
 
 
@@ -198,15 +214,11 @@ async def test__run_ok_parent_changed(worker, loop,
     worker.cfg.max_requests = 0
     worker.cfg.is_ssl = False
 
-    worker._runner = web.AppRunner(worker.wsgi)
-    await worker._runner.setup()
-
     await worker._run()
 
     worker.notify.assert_called_with()
     worker.log.info.assert_called_with("Parent changed, shutting down: %s",
                                        worker)
-    assert worker._runner.server is None
 
 
 async def test__run_exc(worker, loop, aiohttp_unused_port) -> None:
@@ -224,9 +236,6 @@ async def test__run_exc(worker, loop, aiohttp_unused_port) -> None:
     worker.cfg.max_requests = 0
     worker.cfg.is_ssl = False
 
-    worker._runner = web.AppRunner(worker.wsgi)
-    await worker._runner.setup()
-
     def raiser():
         waiter = worker._notify_waiter
         worker.alive = False
@@ -236,70 +245,45 @@ async def test__run_exc(worker, loop, aiohttp_unused_port) -> None:
     await worker._run()
 
     worker.notify.assert_called_with()
-    assert worker._runner.server is None
 
 
-async def test__run_ok_max_requests_exceeded(worker, loop,
-                                             aiohttp_unused_port):
-    skip_if_no_dict(loop)
-
-    worker.ppid = os.getppid()
-    worker.alive = True
-    worker.servers = {}
-    sock = socket.socket()
-    addr = ('localhost', aiohttp_unused_port())
-    sock.bind(addr)
-    worker.sockets = [sock]
-    worker.log = mock.Mock()
-    worker.loop = loop
-    worker.cfg.access_log_format = ACCEPTABLE_LOG_FORMAT
-    worker.cfg.max_requests = 10
-    worker.cfg.is_ssl = False
-
-    worker._runner = web.AppRunner(worker.wsgi)
-    await worker._runner.setup()
-    worker._runner.server.requests_count = 30
-
-    await worker._run()
-
-    worker.notify.assert_called_with()
-    worker.log.info.assert_called_with("Max requests, shutting down: %s",
-                                       worker)
-
-    assert worker._runner.server is None
-
-
-def test__create_ssl_context_without_certs_and_ciphers(worker) -> None:
-    here = pathlib.Path(__file__).parent
+def test__create_ssl_context_without_certs_and_ciphers(
+        worker,
+        tls_certificate_pem_path,
+) -> None:
     worker.cfg.ssl_version = ssl.PROTOCOL_SSLv23
     worker.cfg.cert_reqs = ssl.CERT_OPTIONAL
-    worker.cfg.certfile = str(here / 'sample.crt')
-    worker.cfg.keyfile = str(here / 'sample.key')
+    worker.cfg.certfile = tls_certificate_pem_path
+    worker.cfg.keyfile = tls_certificate_pem_path
     worker.cfg.ca_certs = None
     worker.cfg.ciphers = None
-    crt = worker._create_ssl_context(worker.cfg)
-    assert isinstance(crt, ssl.SSLContext)
+    ctx = worker._create_ssl_context(worker.cfg)
+    assert isinstance(ctx, ssl.SSLContext)
 
 
-def test__create_ssl_context_with_ciphers(worker) -> None:
-    here = pathlib.Path(__file__).parent
+def test__create_ssl_context_with_ciphers(
+        worker,
+        tls_certificate_pem_path,
+) -> None:
     worker.cfg.ssl_version = ssl.PROTOCOL_SSLv23
     worker.cfg.cert_reqs = ssl.CERT_OPTIONAL
-    worker.cfg.certfile = str(here / 'sample.crt')
-    worker.cfg.keyfile = str(here / 'sample.key')
+    worker.cfg.certfile = tls_certificate_pem_path
+    worker.cfg.keyfile = tls_certificate_pem_path
     worker.cfg.ca_certs = None
     worker.cfg.ciphers = 'PSK'
     ctx = worker._create_ssl_context(worker.cfg)
     assert isinstance(ctx, ssl.SSLContext)
 
 
-def test__create_ssl_context_with_ca_certs(worker) -> None:
-    here = pathlib.Path(__file__).parent
+def test__create_ssl_context_with_ca_certs(
+        worker,
+        tls_ca_certificate_pem_path, tls_certificate_pem_path,
+) -> None:
     worker.cfg.ssl_version = ssl.PROTOCOL_SSLv23
     worker.cfg.cert_reqs = ssl.CERT_OPTIONAL
-    worker.cfg.certfile = str(here / 'sample.crt')
-    worker.cfg.keyfile = str(here / 'sample.key')
-    worker.cfg.ca_certs = str(here / 'sample.crt')
+    worker.cfg.certfile = tls_certificate_pem_path
+    worker.cfg.keyfile = tls_certificate_pem_path
+    worker.cfg.ca_certs = tls_ca_certificate_pem_path
     worker.cfg.ciphers = None
     ctx = worker._create_ssl_context(worker.cfg)
     assert isinstance(ctx, ssl.SSLContext)
